@@ -1,5 +1,6 @@
 package #1.#x;
 
+import javax.servlet.http.*;
 import paraselene.*;
 import paraselene.supervisor.*;
 import paraselene.ajax.*;
@@ -12,6 +13,7 @@ import paraselene.dyna.*;
  */
 public class FormJson extends #1.SuperPage {
 	private static final long serialVersionUID = 1L;
+	private boolean opera_f = false;
 	private Tag	script = new Tag( "script", false );
 
 	/**
@@ -97,12 +99,28 @@ public class FormJson extends #1.SuperPage {
 	 * @exception PageException 処理の継続が不可能(ブラウザには500を返す)。
 	 */
 	public Page outputMain( Page from, RequestParameter req ) throws PageException {
-		StringBuilder	buf = new StringBuilder( "<!--\r\n" );
-		buf = buf.append( "parent.paraselene_form_ok('" );
-		buf = buf.append( from.getUniqueKey() );
-		buf = buf.append( "');" );
-		buf = buf.append( "\r\n-->" );
-		script.setValueString( buf.toString() );
+		String[]	ua = req.getHeader( "User-Agent" );
+		boolean	opera_f = false;
+		if ( ua != null ) {
+			opera_f = ua[0].indexOf( "Opera" ) != -1;
+		}
+
+		StringBuilder	buf = new StringBuilder( "" );
+		if ( opera_f ) {
+			buf = buf.append( "parent.paraselene_form_ok('" );
+			buf = buf.append( from.getUniqueKey() );
+			buf = buf.append( "');" );
+		}
+		else {
+			HttpSession	session = req.getSession();
+			JSON	data = Ajax.get( session, from.getUniqueKey() );
+			buf = buf.append( "parent.paraselene_called_form=undefined;" );
+			buf = buf.append( "parent.paraselene_action(" );
+			buf = buf.append( data.toString() );
+			buf = buf.append( ");" );
+		}
+		script.removeHTMLPart();
+		script.addHTMLPart( new paraselene.ajax.data.JavaScript( buf.toString() ) );
 		return this;
 	}
 	public NameDefine[] inspectName( Page page, String ... exclude ){ return null;}
