@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009  Akira Terasaki
+ * Copyright (c) 2009, 2010  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -181,7 +181,10 @@ public abstract class PageFactory extends Thread {
 		synchronized( class_def ) {
 			LinkedList<Page>	que = pre_load.get( id );
 			last_access.put( id, new Date() );
-			int	cnt = que.size();
+			int	cnt = 0;
+			if ( que != null ) {
+				cnt = que.size();
+			}
 			if ( cnt > 0 ) {
 				class_def.notifyAll();
 				return que.poll();
