@@ -22,11 +22,44 @@ public class Popup extends Forward implements AjaxForward {
 		/**
 		 * ポップアップの下のページのUI操作を許す。
 		 */
-		MODELESS,
+		MODELESS( false, true ),
 		/**
 		 * ポップアップの下のページのUI操作を禁止する。
 		 */
-		MODAL
+		MODAL( true, true ),
+		/**
+		 * タイトルバーの無いモーダルダイアログ。
+		 */
+		LITE_MODAL( true, false );
+		private boolean modal_f;
+		private boolean move_f;
+		private Type( boolean md_f, boolean mv_f ) {
+			modal_f = md_f;
+			move_f = mv_f;
+		}
+		/**
+		 * タイトルバーの有無。
+		 * @return true:存在する、false:存在しない。
+		 */
+		public boolean isTitle() {
+			return move_f;
+		}
+		/**
+		 * モーダルであるか？
+		 * @return true:モーダル、false:モードレス。
+		 */
+		public boolean isMode() {
+			return modal_f;
+		}
+		/**
+		 * モーダルであるか？
+		 * @return true:モーダル、false:モードレスまたはダイアログではない。
+		 */
+		public static boolean isMode( Page page ) {
+			Type	ptype = page.getPopupType();
+			if ( ptype == null )	return false;
+			return ptype.isMode();
+		}
 	}
 
 	private Type type;
@@ -39,20 +72,34 @@ public class Popup extends Forward implements AjaxForward {
 	public Popup( PageID id, Type dialog_type ) {
 		super( id );
 		type = dialog_type;
-		History	hist = SandBox.getCurrentRequestParameter().getHistory();
-		if ( hist != null ) {
-			Page[]	page = hist.getBrowsingPage();
-			Popup.Type	ptype = Popup.Type.MODELESS;
-			for ( int i = 0; i < page.length; i++ ) {
-				if ( page[i].getPopupType() == Popup.Type.MODAL ) {
-					ptype = Popup.Type.MODAL;
-					break;
-				}
-			}
-			overwriteType( ptype );
+		if ( isModelessAlert( type, SandBox.getCurrentRequestParameter().getHistory(), false ) ) {
+			overwriteType( Type.MODAL );
 		}
 	}
 
+	static boolean isModeless( Type mine ) {
+		if ( mine == null )	return false;
+		return !mine.isMode();
+	}
+
+	static boolean isModelessAlert( Type mine, History hist, boolean unlock_f ) {
+		if ( hist == null )	return false;
+		if ( mine == null )	return false;
+		if ( mine.isMode() )	return false;
+		try {
+			Page[]	page = hist.getBrowsingPage();
+			for ( int i = 0; i < page.length; i++ ) {
+				Type	ptype = page[i].getPopupType();
+				if ( ptype == null )	continue;
+				if ( ptype.isMode() )	return true;
+			}
+		}
+		finally {
+			if ( unlock_f )	hist.unlock();
+		}
+		return false;
+	}
+
 	/**
 	 * コンストラクタ。
 	 * 指定ページの Z順を手前にします。
