@@ -88,30 +88,55 @@ public class RequestParameter implements Serializable {
 		 * (ページの文言を解析して、適した掲載広告を決定します)です。
 		 * Google の検索結果自体には影響しません。
 		 */
-		GOOGLE_ADSENSE( "mediapartners-google" ),
+		GOOGLE_ADSENSE( "Mediapartners-Google" ),
 		/**
 		 * Google。
 		 * Google の検索結果自体に反映するためのクローラーです。
 		 */
-		GOOGLE( "googlebot" ),
+		GOOGLE( "Googlebot" ),
 		/**
 		 * Yahoo!。
 		 */
-		YAHOO( "yahoo!", "slurp" ),
+		YAHOO( "Yahoo!", "Slurp" ),
 		/**
-		 * bing。
+		 * Yahoo JAPAN。
+		 */
+		YAHOO_JAPAN( "Y!J" ),
+		/**
+		 * Bing。
 		 */
 		MSN( "msnbot" ),
 		/**
 		 * 百度。
 		 */
-		BAIDU( "baiduspider" ),
+		BAIDU( "Baiduspider" ),
+		/**
+		 * NAVER。
+		 */
+		NAVER( "Yeti" ),
+		/**
+		 * Яндекс。
+		 */
+		YANDEX( "Yandex" ),
+		/**
+		 * Cuil。
+		 */
+		CUIL( "Twiceler" ),
+		/**
+		 * Alexa。
+		 */
+		ALEXA( "ia_archive" ),
 		/**
 		 * 検索エンジンではない。
 		 */
 		NO_SEARCHENGINE();
 		private String[]	str = null;
-		private SearchEngine( String ... s ) { str = s; }
+		private SearchEngine( String ... s ) {
+			str = new String[s.length];
+			for ( int i = 0; i < str.length; i++ ) {
+				str[i] = s[i].toLowerCase( Locale.ENGLISH );
+			}
+		}
 		boolean isHit( String ua ) {
 			if ( str == null )	return true;
 			for ( int i = 0; i < str.length; i++ ) {
@@ -195,7 +220,7 @@ public class RequestParameter implements Serializable {
 	}
 
 	/**
-	 * ユーザーエージェントから、携帯キャリアを判定する。
+	 * ユーザーエージェントから、検索エンジンクローラーを判定する。
 	 * @return 判定結果。
 	 */
 	public SearchEngine judgeSearchEngine() {
@@ -442,7 +467,7 @@ public class RequestParameter implements Serializable {
 	}
 
 	/**
-	 * リクエストされたURIの取得。
+	 * リクエストされたURIの取得。クエリも含めたフルパスです。
 	 * @return URI。
 	 */
 	public URI getURI() {
@@ -450,7 +475,7 @@ public class RequestParameter implements Serializable {
 	}
 
 	/**
-	 * リクエストされたURIの取得。
+	 * リクエストされたURIの取得。コンテキストパスを含まない、相対パスです。
 	 * @return URI。
 	 */
 	public URI getRelativeURI() {
@@ -628,5 +653,21 @@ public class RequestParameter implements Serializable {
 	public boolean isExistRequestItem() {
 		return item_map.size() > 0;
 	}
+
+	String makeCacheKey() {
+		if ( getMethod() != Method.GET )	return null;
+		String[]	key = getAllKey();
+		int	code = 0;
+		for ( int i = 0; i < key.length; i++ ) {
+			code += key.hashCode();
+			RequestItem	item = getItem( key[i] );
+			String[]	val = item.getAllValue();
+			for ( int j = 0; j < val.length; j++ ) {
+				code += val[j].hashCode();
+			}
+		}
+		code ^= getRelativeURI().hashCode();
+		return Integer.toString( code, Character.MAX_RADIX );
+	}
 }
 
