@@ -51,20 +51,10 @@ class SessionData implements Serializable, HttpSessionBindingListener {
 	private ArrayList<String>	cache_dummy_key = new ArrayList<String>();
 	private ArrayList<CacheAjax>	cache_ajax = new ArrayList<CacheAjax>();
 	private HashMap<String, Waiter>	working_ajax = new HashMap<String, Waiter>();
+	private static final int CACHE_MAX = 5;
 
 	private String getCacheKey( RequestParameter param ) {
-		RequestItem	item = param.getItem( DUMMY );
-		if ( item == null )	return null;
-		String	key = item.getValue( 0 );
-		if ( key == null )	return null;
-		key = key.trim();
-		if ( key.isEmpty() )	return null;
-		try{
-			int	dmy = Integer.parseInt( key );
-			if ( dmy < 0 )	return null;
-		}
-		catch( Exception e ){}
-		return key;
+		return param.makeCacheKey();
 	}
 
 	void cacheEntry( RequestParameter param, CacheAjax ca ) {
@@ -73,7 +63,7 @@ class SessionData implements Serializable, HttpSessionBindingListener {
 		synchronized( cache_dummy_key ) {
 			cache_dummy_key.add( key );
 			cache_ajax.add( ca );
-			if ( cache_dummy_key.size() > 5 ) {
+			if ( cache_dummy_key.size() > CACHE_MAX ) {
 				cache_dummy_key.remove( 0 );
 				cache_ajax.remove( 0 );
 			}
