@@ -58,9 +58,9 @@ public abstract class Supervisor extends HttpServlet {
 		"", "http://", "https://"
 	};
 
-	private static HashMap<Thread,DataHolder>	data_map_th
+	private static volatile HashMap<Thread,DataHolder>	data_map_th
 		= new HashMap<Thread,DataHolder>();
-	private static HashMap<Supervisor,DataHolder>	data_map_sv
+	private static volatile HashMap<Supervisor,DataHolder>	data_map_sv
 		= new HashMap<Supervisor,DataHolder>();
 
 	static {
