@@ -37,6 +37,19 @@ public class CheckBox extends Input {
 	}
 
 	private boolean radio_flag = false;
+	private RadioGroup	radio = null;
+
+	void setRadioGroup( RadioGroup r ) {
+		radio = r;
+	}
+
+	/**
+	 * 所属しているラジオグループを返す。
+	 * @return 所属グループ。
+	 */
+	public RadioGroup getRadioGroup() {
+		return radio;
+	}
 
 	/**
 	 * コンストラクタ。
