@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009  Akira Terasaki
+ * Copyright (c) 2009, 2010  Akira Terasaki
  * このファイルは同梱されている License.txt に定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -37,7 +37,7 @@ public class ColorMake {
 		SourceHead.init( new File( "../template/head.txt" ) );
 		bw.write( SourceHead.getHead( new_file ) );
 		bw.write( "package paraselene;\n\n" );
-		bw.write( "/**\n * Web140色定義。\n" );
+		bw.write( "/**\n * Web140色定義。140色に加え、TRANSPARENT(透明)も存在します。\n" );
 		while( true ) {
 			String	line = br.readLine();
 			if ( line == null )	break;
